==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/zh/generic.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "上周二",
	"field-year": "年",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "分钟",
	"field-tue-narrow-relative+0": "本周二",
	"field-tue-narrow-relative+1": "下周二",
	"field-thu-short-relative+0": "本周四",
	"dateTimeFormat-short": "{1} {0}",
	"field-thu-short-relative+1": "下周四",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"field-day-relative+2": "后天",
	"field-wed-narrow-relative+-1": "上周三",
	"field-year-narrow": "年",
	"field-tue-relative+0": "本周二",
	"field-tue-relative+1": "下周二",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "M月d日",
	"field-week-relative+0": "本周",
	"field-month-relative+0": "本月",
	"field-week-relative+1": "下周",
	"field-month-relative+1": "下个月",
	"field-sun-narrow-relative+0": "本周日",
	"field-mon-short-relative+0": "本周一",
	"field-sun-narrow-relative+1": "下周日",
	"field-mon-short-relative+1": "下周一",
	"field-second-relative+0": "现在",
	"dateFormatItem-yyyyQQQ": "Gy年第Q季度",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "Gy年MM月d日E",
	"dateFormatItem-yyyyMd": "G y/M/d",
	"field-day": "日",
	"field-year-relative+-1": "去年",
	"field-sat-short-relative+-1": "上周六",
	"field-hour-relative+0": "这一时间 / 此时",
	"dateFormatItem-yyyyMEd": "G y/M/dE",
	"field-wed-relative+-1": "上周三",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "上周六",
	"field-second": "秒",
	"dateFormat-long": "Gy年MM月d日",
	"dateFormatItem-GyMMMd": "Gy年MM月d日",
	"field-quarter": "季度",
	"field-week-short": "周",
	"field-tue-short-relative+0": "本周二",
	"field-tue-short-relative+1": "下周二",
	"field-mon-relative+-1": "上周一",
	"dateFormatItem-GyMMM": "Gy年MM月",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "LL",
	"field-minute-short": "分",
	"field-dayperiod": "上午/下午",
	"field-sat-short-relative+0": "本周六",
	"field-sat-short-relative+1": "下周六",
	"dateFormat-medium": "Gy年MM月d日",
	"dateFormatItem-yyyyMMMM": "Gy年M月",
	"dateFormatItem-yyyyM": "Gy年M月",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "本周一",
	"field-mon-relative+1": "下周一",
	"field-year-short": "年",
	"field-quarter-relative+-1": "上季度",
	"dateFormatItem-yyyyMMMd": "Gy年MM月d日",
	"field-sat-relative+-1": "上周六",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "小时",
	"dateFormat-full": "Gy年MM月d日EEEE",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "季",
	"field-sat-narrow-relative+0": "本周六",
	"field-fri-relative+0": "本周五",
	"field-sat-narrow-relative+1": "下周六",
	"field-fri-relative+1": "下周五",
	"field-sun-short-relative+0": "本周日",
	"field-sun-short-relative+1": "下周日",
	"field-week-relative+-1": "上周",
	"field-quarter-relative+0": "本季度",
	"field-minute-relative+0": "此刻",
	"field-quarter-relative+1": "下季度",
	"field-wed-short-relative+-1": "上周三",
	"dateFormat-short": "Gy/M/d",
	"field-thu-short-relative+-1": "上周四",
	"dateFormatItem-yyyyMMMEd": "Gy年MM月d日E",
	"field-mon-narrow-relative+-1": "上周一",
	"dateFormatItem-MMMMd": "M月d日",
	"field-thu-narrow-relative+-1": "上周四",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "上周二",
	"dateFormatItem-H": "H时",
	"dateFormatItem-yyyy": "Gy年",
	"field-wed-short-relative+0": "本周三",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "下周三",
	"field-sun-relative+-1": "上周日",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "工作日",
	"field-sat-relative+0": "本周六",
	"dateFormatItem-h": "ah时",
	"field-sat-relative+1": "下周六",
	"dateFormatItem-MEd": "M/dE",
	"dateFormatItem-y": "Gy年",
	"field-thu-narrow-relative+0": "本周四",
	"field-thu-narrow-relative+1": "下周四",
	"field-sun-narrow-relative+-1": "上周日",
	"field-mon-short-relative+-1": "上周一",
	"field-thu-relative+0": "本周四",
	"field-thu-relative+1": "下周四",
	"dateFormatItem-hms": "ah:mm:ss",
	"field-fri-short-relative+-1": "上周五",
	"field-thu-relative+-1": "上周四",
	"field-week": "周",
	"dateFormatItem-Ed": "d日E",
	"field-wed-narrow-relative+0": "本周三",
	"field-wed-narrow-relative+1": "下周三",
	"dateFormatItem-yyyyMMM": "Gy年MM月",
	"field-fri-short-relative+0": "本周五",
	"field-fri-short-relative+1": "下周五",
	"dateFormatItem-yyyyQQQQ": "Gy年第Q季度",
	"field-hour-short": "小时",
	"field-month-narrow": "月",
	"field-hour-narrow": "小时",
	"field-fri-narrow-relative+-1": "上周五",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-fri-relative+-1": "上周五",
	"field-tue-short-relative+-1": "上周二",
	"field-minute-narrow": "分",
	"field-mon-narrow-relative+0": "本周一",
	"field-mon-narrow-relative+1": "下周一",
	"field-zone": "时区",
	"dateFormatItem-MMMEd": "M月d日E",
	"field-quarter-narrow": "季",
	"field-sun-short-relative+-1": "上周日",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"dateFormatItem-Gy": "Gy年",
	"field-day-short": "日",
	"field-week-narrow": "周",
	"field-era": "纪元",
	"field-fri-narrow-relative+0": "本周五",
	"field-fri-narrow-relative+1": "下周五"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/zh/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "本季度",
	"field-quarter-short-relative+1": "下季度",
	"field-tue-relative+-1": "上周二",
	"field-year": "年",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "分钟",
	"field-month-narrow-relative+-1": "上个月",
	"field-tue-narrow-relative+0": "本周二",
	"field-tue-narrow-relative+1": "下周二",
	"field-day-short-relative+-1": "昨天",
	"field-thu-short-relative+0": "本周四",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "今天",
	"field-day-short-relative+-2": "前天",
	"field-thu-short-relative+1": "下周四",
	"field-day-relative+1": "明天",
	"field-week-narrow-relative+0": "本周",
	"field-day-relative+2": "后天",
	"field-week-narrow-relative+1": "下周",
	"dateFormatItem-EBhms": "EB h:mm:ss",
	"field-wed-narrow-relative+-1": "上周三",
	"field-year-narrow": "年",
	"field-era-short": "纪元",
	"field-year-narrow-relative+0": "今年",
	"field-tue-relative+0": "本周二",
	"field-year-narrow-relative+1": "明年",
	"field-tue-relative+1": "下周二",
	"field-weekdayOfMonth": "月中日",
	"field-second-short": "秒",
	"dateFormatItem-MMMd": "M月d日",
	"field-weekdayOfMonth-narrow": "月中日",
	"field-week-relative+0": "本周",
	"field-month-relative+0": "本月",
	"field-week-relative+1": "下周",
	"field-month-relative+1": "下个月",
	"field-sun-narrow-relative+0": "本周日",
	"field-mon-short-relative+0": "本周一",
	"field-sun-narrow-relative+1": "下周日",
	"field-mon-short-relative+1": "下周一",
	"field-second-relative+0": "现在",
	"dateFormatItem-yyyyQQQ": "Gy年第Q季度",
	"field-weekOfMonth": "月中周",
	"field-month-short": "月",
	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
	"dateFormatItem-yyyyMd": "G y/M/d",
	"field-day": "日",
	"field-dayOfYear-short": "年中日",
	"field-year-relative+-1": "去年",
	"field-sat-short-relative+-1": "上周六",
	"field-hour-relative+0": "这一时间 / 此时",
	"dateFormatItem-yyyyMEd": "G y/M/dE",
	"field-second-short-relative+0": "现在",
	"field-wed-relative+-1": "上周三",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "上周六",
	"field-second": "秒",
	"dateFormatItem-Ehms": "Ea h:mm:ss",
	"dateFormat-long": "Gy年M月d日",
	"dateFormatItem-GyMMMd": "Gy年M月d日",
	"field-hour-short-relative+0": "这一时间 / 此时",
	"field-quarter": "季度",
	"field-week-short": "周",
	"field-day-narrow-relative+0": "今天",
	"field-day-narrow-relative+1": "明天",
	"field-day-narrow-relative+2": "后天",
	"field-tue-short-relative+0": "本周二",
	"field-tue-short-relative+1": "下周二",
	"field-month-short-relative+-1": "上个月",
	"field-mon-relative+-1": "上周一",
	"dateFormatItem-GyMMM": "Gy年M月",
	"field-month": "月",
	"field-day-narrow": "日",
	"dateFormatItem-MMM": "LL",
	"field-minute-short": "分",
	"field-dayperiod": "上午/下午",
	"field-sat-short-relative+0": "本周六",
	"field-sat-short-relative+1": "下周六",
	"dateFormat-medium": "Gy年M月d日",
	"dateFormatItem-yyyyMMMM": "Gy年M月",
	"dateFormatItem-yyyyM": "Gy年M月",
	"field-second-narrow": "秒",
	"field-mon-relative+0": "本周一",
	"field-mon-relative+1": "下周一",
	"field-day-narrow-relative+-1": "昨天",
	"field-year-short": "年",
	"field-day-narrow-relative+-2": "前天",
	"field-quarter-relative+-1": "上季度",
	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
	"field-dayperiod-narrow": "上午/下午",
	"field-week-narrow-relative+-1": "上周",
	"field-dayOfYear": "年中日",
	"field-sat-relative+-1": "上周六",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M/d",
	"field-hour": "小时",
	"field-minute-narrow-relative+0": "此刻",
	"dateFormat-full": "Gy年M月d日EEEE",
	"field-month-relative+-1": "上个月",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "季",
	"field-sat-narrow-relative+0": "本周六",
	"field-fri-relative+0": "本周五",
	"field-sat-narrow-relative+1": "下周六",
	"field-fri-relative+1": "下周五",
	"dateFormatItem-EBhm": "EB h:mm",
	"field-month-narrow-relative+0": "本月",
	"field-month-narrow-relative+1": "下个月",
	"field-sun-short-relative+0": "本周日",
	"field-sun-short-relative+1": "下周日",
	"field-week-relative+-1": "上周",
	"field-quarter-short-relative+-1": "上季度",
	"dateFormatItem-Ehm": "Ea h:mm",
	"field-minute-short-relative+0": "此刻",
	"field-quarter-relative+0": "本季度",
	"field-minute-relative+0": "此刻",
	"field-quarter-relative+1": "下季度",
	"field-wed-short-relative+-1": "上周三",
	"dateFormat-short": "Gy/M/d",
	"dateFormatItem-Bh": "Bh时",
	"field-year-narrow-relative+-1": "去年",
	"field-thu-short-relative+-1": "上周四",
	"dateFormatItem-yyyyMMMEd": "Gy年MM月d日E",
	"field-mon-narrow-relative+-1": "上周一",
	"dateFormatItem-MMMMd": "M月d日",
	"field-thu-narrow-relative+-1": "上周四",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "H时",
	"field-weekOfMonth-short": "月中周",
	"field-tue-narrow-relative+-1": "上周二",
	"dateFormatItem-yyyy": "Gy年",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "本周三",
	"field-wed-short-relative+1": "下周三",
	"field-sun-relative+-1": "上周日",
	"dateTimeFormat-full": "{1} {0}",
	"field-second-narrow-relative+0": "现在",
	"dateFormatItem-hm": "ah:mm",
	"dateFormatItem-d": "d日",
	"field-weekday": "工作日",
	"field-day-short-relative+0": "今天",
	"field-quarter-narrow-relative+0": "本季度",
	"field-day-short-relative+1": "明天",
	"field-sat-relative+0": "本周六",
	"field-quarter-narrow-relative+1": "下季度",
	"dateFormatItem-h": "ah时",
	"field-day-short-relative+2": "后天",
	"field-sat-relative+1": "下周六",
	"field-week-short-relative+0": "本周",
	"field-week-short-relative+1": "下周",
	"field-dayOfYear-narrow": "年中日",
	"field-month-short-relative+0": "本月",
	"field-month-short-relative+1": "下个月",
	"field-weekdayOfMonth-short": "月中日",
	"dateFormatItem-MEd": "M/dE",
	"field-zone-narrow": "时区",
	"dateFormatItem-y": "Gy年",
	"field-thu-narrow-relative+0": "本周四",
	"field-sun-narrow-relative+-1": "上周日",
	"field-mon-short-relative+-1": "上周一",
	"field-thu-narrow-relative+1": "下周四",
	"field-thu-relative+0": "本周四",
	"field-thu-relative+1": "下周四",
	"dateFormatItem-hms": "ah:mm:ss",
	"field-fri-short-relative+-1": "上周五",
	"field-thu-relative+-1": "上周四",
	"field-week": "周",
	"dateFormatItem-Ed": "d日E",
	"field-wed-narrow-relative+0": "本周三",
	"field-wed-narrow-relative+1": "下周三",
	"field-quarter-narrow-relative+-1": "上季度",
	"field-year-short-relative+0": "今年",
	"dateFormatItem-yyyyMMM": "Gy年M月",
	"field-dayperiod-short": "上午/下午",
	"field-year-short-relative+1": "明年",
	"field-fri-short-relative+0": "本周五",
	"field-fri-short-relative+1": "下周五",
	"field-week-short-relative+-1": "上周",
	"field-hour-narrow-relative+0": "这一时间 / 此时",
	"dateFormatItem-yyyyQQQQ": "Gy年第Q季度",
	"field-hour-short": "小时",
	"field-zone-short": "时区",
	"field-month-narrow": "月",
	"field-hour-narrow": "小时",
	"field-fri-narrow-relative+-1": "上周五",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-era-narrow": "纪元",
	"field-fri-relative+-1": "上周五",
	"dateFormatItem-Bhms": "Bh:mm:ss",
	"field-tue-short-relative+-1": "上周二",
	"field-minute-narrow": "分",
	"field-mon-narrow-relative+0": "本周一",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "下周一",
	"field-year-short-relative+-1": "去年",
	"field-zone": "时区",
	"dateFormatItem-MMMEd": "M月d日E",
	"field-weekOfMonth-narrow": "月中周",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-weekday-narrow": "工作日",
	"field-quarter-narrow": "季",
	"field-sun-short-relative+-1": "上周日",
	"field-day-relative+-1": "昨天",
	"field-day-relative+-2": "前天",
	"field-weekday-short": "工作日",
	"dateFormatItem-Bhm": "Bh:mm",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"dateFormatItem-Gy": "Gy年",
	"field-day-short": "日",
	"field-week-narrow": "周",
	"field-era": "纪元",
	"field-fri-narrow-relative+0": "本周五",
	"field-fri-narrow-relative+1": "下周五"
}
//end v1.x content
);
